function IL=ADSLIL(loopno,freq,len)
%ADSLIL - Get get insertion loss given a ADSL loop, a freq. axis, and a length
%
% Parameter:    loopno     Loop number to test
% Parameter:    freq       Frequency for test [Hz]
% Parameter:    len        Length of loop [m]
% Returns:      IL         Insertion loss [dB]
%
% Example(s):
%               % Insertion loss @ 300kHz for Loop#3 with a length of 2840m:
%               ADSLIL(3,300e3,2840)
%               % Find the reach for insertion loss 40.4069 @ 300kHz:
%               fzero(inline('ADSLIL(1,300e3,x)-40.4069'),2000)
%% ===========================================================================
 
%% ===========================================================================
% Copyright (C):
%       2001-2002 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : B1, FTW
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: ADSLIL.m,v 1.2 2002/01/25 12:14:35 tono Exp $               
%% ===========================================================================

%% ===========================================================================
% Change History
%      2001-07-03 (ToNo) Created
%      2002-01-25 (ToNo) Changed the IL calc to be more direct
%% ===========================================================================
global ex;

scenario = sprintf('ETSI-ADSL-Loop%d',loopno);
ttlist  = etsi_loopsADSL([],len);   

tt      = getList(ttlist,scenario);     % Get the selected scenario
segs    = size(tt.topology);
IL      = -getAtt(ex,1,segs(1),tt.topology,freq,ex.param.Zterm);
