% function AdjustForPBO()
%% ===========================================================================
% Copyright (C) 2002 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Description   : ADSL performance simulations, 
%                 Adjusting for ADSL power cut back
%
% Project       : FTW, B1
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% Reference:
%    ETSI STC TM6 Draft RTS/TM-06006 rev 10a (ADSL), 2001-05
%
% CVS:       $Id: AdjustForPOB.m,v 1.1 2002/03/12 14:50:24 tono Exp $
%% ===========================================================================

%% ===========================================================================
% Change History
%      2002-01-31 (ToNo) Created
%% ===========================================================================
global ex;
global result;

%% ===========================================================================
% Adjust the results

df	 = 4.3125e3;           % Carrier spacing in Hz
dmttones = [df:df:256*df];

if overPOTS,
    POBtones=7:18;
    POBlimits=[ 3 4 5 6 7 8 9];
    POBreductions=[ 0 2 4 6 8 10 12];
else
    POBtones=40:51;
    POBlimits=[ 0 1.5 3 4.5 6 7.5 9];
    POBreductions=[ 0 2 4 6 8 10 12];
end 

% Get the recieved energy on the US tones
RxLTtones=interp1(ex.param.frequency.f,result.LT.Rx_signal,dmttones(POBtones));
POBpower=10*log10(sum(RxLTtones*df));

pix      = find(POBpower>POBlimits);
if length(pix)>0,
    powerred = POBreductions(pix(end));
    pred     = 10^(powerred/10);
    
    result.LT.Tx_signal = result.LT.Tx_signal/pred;
    result.NT.Rx_signal = result.NT.Rx_signal/pred;
end;