function P=etsi_PSDmasksSCM(name)
%% ===========================================================================
%etsi_PSDmasksSCM - Sets up the SCM PSD masks according to ETSI VDSL part 2
%
% Parameter:    name    SCM plan name
% Returns:      P       Resulting plan (center frequencies and symbol rate)
%
% Reference:
%   ETSI VDSL part 2, TS 101 270-2 v1.1.5
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2000-2002 by FTW, Wien, Austria;  
%                                                         All rights reserved.
% Project       : FTW xDSL simulator
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: etsi_PSDmasksSCM.m,v 1.6 2002/06/05 15:26:00 tono Exp $
%% ===========================================================================
% Change History
%      1999-08-18 (DaB)  Created
%      1999-10-25 (ToNo) Reorganized things into etsi,ansi,itu,fsan definitions
%      2000-05-05 (UvAn) Uppdated the SCM masks according to 
%                        TS 101 270-2 v0.1.2 spec
%      2002-04-17 (ToNo) Uppdated the SCM masks according to 
%                        TS 101 270-2 v1.1.5 spec
%% ===========================================================================

% Input name to generate PSD mask for SCM
% ---------------------------------------
switch name,
case 'A1M',
   % A1-02OAG-M ETSI profile
   %----------------
   A1M.fs.down=[1.62e6];
   A1M.fs.up=[1.215e6];
   A1M.fc.down=[1.89e6];
   A1M.fc.up=[3.8475e6];
   P=A1M;
case 'A2M',
   % A2-02OAG-M ETSI profile
   %----------------
   A2.fs.down=[1.62e6];
   A2.fs.up=[1.215e6];
   A2.fc.down=[1.89e6];
   A2.fc.up=[3.8475e6];
   P=A2;
case 'A3M',
   % A3-01OAG-M ETSI profile
   %----------------
   A3M.fs.down=[1.620e6 1.215e6];
   A3M.fs.up=[1.215e6];
   A3M.fc.down=[1.89e6 6.2775e6];
   A3M.fc.up=[3.8475e6];
   P=A3M;
case 'S1M',
   % S1-02OAG-M ETSI profile
   %----------------
   S1M.fs.down=[1.62e6];
   S1M.fs.up=[1.62e6 0.81e6];
   S1M.fc.down=[1.89e6];
   S1M.fc.up=[4.1175e6 8.37e6];
   P=S1M;
case 'S2M',
   % S2-03OAG-M ETSI profile
   %----------------
   S2M.fs.down=[1.62e6];
   S2M.fs.up=[1.62e6 1.62e6];
   S2M.fc.down=[1.89e6];
   S2M.fc.up=[4.1175e6 8.8425e6];
   P=S2M;
case 'S3M',
   % S3-00OAG-M ETSI profile
   %----------------
   S3M.fs.down=[1.62e6 1.215e6];
   S3M.fs.up=[1.62e6 2.7e6];
   S3M.fc.down=[1.89e6 6.2775e6];
   S3M.fc.up=[4.1175e6 9.5175e6];
   P=S3M;
      
case 'A1R1',
   % A1-02OAG-R1 ETSI profile
   %----------------
   A1R1.fs.down=[1.89e6];
   A1R1.fs.up=[0.81e6];
   A1R1.fc.down=[2.0925e6];
   A1R1.fc.up=[4.455e6];
   P=A1R1;
case 'A2R1',
   % A2-02OAG-R1 ETSI profile
   %----------------
   A2R1.fs.down=[2.16e6];
   A2R1.fs.up=[0.81e6];
   A2R1.fc.down=[2.2275e6];
   A2R1.fc.up=[4.455e6];
   P=A2R1;
case 'A3R1',
   % A3-01OAG-R1 ETSI profile
   %----------------
   A3R1.fs.down=[2.16e6 2.16e6];
   A3R1.fs.up=[0.945e6];
   A3R1.fc.down=[2.2275e6 6.885e6];
   A3R1.fc.up=[4.5225e6];
   P=A3R1;
case 'A4R1',
   % A4-01OAG-R1 ETSI profile
   %----------------
   A4R1.fs.down=[2.16e6 2.16e6];
   A4R1.fs.up=[0.945e6];
   A4R1.fc.down=[2.2275e6 6.885e6];
   A4R1.fc.up=[4.5225e6];
   P=A4R1;
case 'S1R1',
   % S1-02OAG-R1 ETSI profile
   %----------------
   S1R1.fs.down=[1.89e6];
   S1R1.fs.up=[0.945e6 1.4175e6];
   S1R1.fc.down=[2.0925e6];
   S1R1.fc.up=[4.5225e6 10.125e6];
   P=S1R1;
case 'S2R1',
   % S2-03OAG-R1 ETSI profile
   %----------------
   S2R1.fs.down=[2.16e6];
   S2R1.fs.up=[0.945e6 1.89e6];
   S2R1.fc.down=[2.2275e6];
   S2R1.fc.up=[4.5225e6 10.395e6];
   P=S2R1;
case 'S3R1',
   % S3-00OAG-R1 ETSI profile
   %----------------
   S3R1.fs.down=[2.16e6 2.16e6];
   S3R1.fs.up=[0.945e6 2.16e6];
   S3R1.fc.down=[2.2275e6 6.885e6];
   S3R1.fc.up=[4.5225e6 10.53e6];
   P=S3R1;
   
otherwise
   sprintf('Unknown mask');
end;
