function clist = itu_cables(clist);
%% ===========================================================================
%itu_cables(clist) - Sets up the cable models for ETSI
%
% Parameter:    clist          Structure describing the cables
% Returns:      clist          Structure describing the cables
%
% Example(s):
%   ex.clist   = itu_cables(ex.clist);               % Add to existing clist
%   cableparam = getList(ex.clist,'ITU-ADSL-PE032'); % Get ETSI PE 0.32 cable
%
% Reference:
%   ITU G.996.1 (Draft)
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2000-2002 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: itu_cables.m,v 1.2 2002/03/18 11:59:07 tono Exp $
% Change History
%      2000-09-09 (ToNo) Created to support G.996.1
%      2000-09-14 (ToNo) Changed 1100 into 1105 to cover the whole ADSL range
%      2002-03-18 (ToNo) Switched to parametric model instead of the tables
%% ===========================================================================

% Use the definitions of the ITU cables in the ETSI standard definitions    

if length(clist)    == 0
    clist = etsi_cables([]);
end;

cable=getList(clist,'ETSI-ADSL-PE032i');

if length(cable)    == 0
    fprintf('Warning: itu_cables depend on etsi_cables\n');
    clist = etsi_cables(clist);
    cable=getList(clist,'ETSI-ADSL-PE032i');
end;

cable.name='ITU-ADSL-PE032';
clist=insertList(clist,cable);
    
cable=getList(clist,'ETSI-ADSL-PE04i');
cable.name='ITU-ADSL-PE04';
clist=insertList(clist,cable);
    
cable=getList(clist,'ETSI-ADSL-PE05i');
cable.name='ITU-ADSL-PE05';
clist=insertList(clist,cable);
    
cable=getList(clist,'ETSI-ADSL-PE063i');
cable.name='ITU-ADSL-PE063';
clist=insertList(clist,cable);

cable=getList(clist,'ETSI-ADSL-PE09i');
cable.name='ITU-ADSL-PE09';
clist=insertList(clist,cable);
    
