function lc = lcDefADSLDMT;
%% ===========================================================================
%lcDefDMT - Sets up the lincode description structure for DMT
% Returns:      lc	The linecode structure
%
% Example(s):
%
% Algorithmic details:
%   Fill in the modemdef structure according to default parameters and input
%   parameters.
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2001 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: lcDefADSLDMT.m,v 1.5 2001/09/21 13:46:53 tono Exp $
%% ===========================================================================
% Change History
%      1999-10-11 (ToNo) Created
%      2000-01-12 (Dab)  lc function changed
%      2000-04-04 (Dab)  added signal margin
%      2001-07-03 (ToNo) Added active tones
%      2001-09-12 (ToNo) Add support for "Maximum aggregate transmit power"
%% ===========================================================================

lc.name           	= 'ADSL-DMT';

% Default Parameter values

% get the margin
lc.param.signal_margin  = 0;
lc.param.xtalk_margin   = 6;
lc.param.refSNR         = 9.8;
lc.param.codingGain     = 3.5;
lc.param.SNRloss        = 0;
lc.param.Px             = 20.4;
lc.param.PxUp           = 12.5;
lc.param.PxDown         = 20.4;

% Param digital
lc.param.dmt.df		= 4.3125e3;      % Carrier spacing 
lc.param.dmt.carriers   = 256;           % Number of carriers used
lc.param.fs             = lc.param.dmt.df*lc.param.dmt.carriers*2; % Sampling frequency
lc.param.dmt.cp         = 40;            % Cyclic prefix value (actually all extensions)
lc.param.dmt.cs         = 0;             % Cyclic suffix value
lc.param.dmt.my         = 0;             % Sampels used for windowing
lc.param.dmt.beta       = 0;             % Sampels used for pulse shaping

% Set up active tones (default is set to EC ADSL over POTS)
lc.param.dmt.tonesus    = [7:30];        % Upstream active tones
lc.param.dmt.tonesds    = [38:63,65:255]; % Downstream active tones
lc.param.dmt.srate      = 4e3;           % DMT symbol rate
lc.param.constellation  = (2:15);        % Bit constellation supported
lc.param.SNRMax         = 58;

lc.param.efficiencyLoss = 1-2*lc.param.dmt.carriers./ ...
    (lc.param.dmt.cp+lc.param.dmt.cs+lc.param.dmt.my+lc.param.dmt.beta+lc.param.dmt.carriers*2);
lc.param.alpha           = 0;

lc.calcRate 		= 'calcResultDMT';
lc.lcPrint 		= 'lcPrintDMT';
