function lcPrintDMT(lc);
%% ===========================================================================
%lcPrintDMT - Print the lincode description structure for DMT
%
% Parameter:    lc     Line code structure to print
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2001 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: lcPrintDMT.m,v 1.3 2001/08/20 10:28:42 tono Exp $
%% ===========================================================================
% Change History
%      1999-10-12 (ToNo) Created
%      2000-01-12 (DaB)  Modified
%      2000-04-04 (Dab)  Added signal margin
%      2001-07-03 (ToNo) Added active tones    
%% ===========================================================================
fprintf('Line code name: %s\n',lc.name);


fprintf('SNR ref=%gdB, xtalk_margin=%gdB, signal_margin=%gdB, coding gain=%gdB, loss=%gdB, SNRmax=%gdB\n',...
lc.param.refSNR,...
lc.param.xtalk_margin,...
lc.param.signal_margin,...
lc.param.codingGain,...
lc.param.SNRloss,...
lc.param.SNRMax);

fprintf('Maximum Power=%g dBm \n',lc.param.Px);

% Param digital
fprintf('Sample rate=%gMHz, carriers=%d, spacing=%gkHz\n',...
lc.param.fs/1e6     ,...
lc.param.dmt.carriers,...
lc.param.dmt.df/1e3);

fprintf('Tones used US:%d-%d; DS:%d-%d (#64=%d, #96=%d)\n',...
min(lc.param.dmt.tonesus),max(lc.param.dmt.tonesus)     ,...
min(lc.param.dmt.tonesds),max(lc.param.dmt.tonesds)     ,...
sum(lc.param.dmt.tonesds==64), ...
sum(lc.param.dmt.tonesds==96));

fprintf('DMT structure cp=%d, cs=%d, my=%d, beta=%d => Efficiency Loss=%2.2f%%\n',...
lc.param.dmt.cp ,...
lc.param.dmt.cs ,...
lc.param.dmt.my ,...
lc.param.dmt.beta,...
lc.param.efficiencyLoss*100);
          
fprintf('Constellation sizes between %d and %d\n',...
min(lc.param.constellation),max(lc.param.constellation));

